@@ -353,15 +353,19 @@ fn str_windows(line: &str, n: usize) -> impl Iterator<Item = &str> {
 /// Functions of the standard library.
 #[cfg(feature = "parse")]
 pub fn funs() -> impl Iterator<Item = Filter<Native<Val>>> {
-    let base_run = base_funs().into_vec().into_iter().map(run);
-    base_run.chain([run(parse_fun())])
+    base_funs().chain([run(parse_fun())])
+}
+
+/// Minimal set of filters for JSON values.
+pub fn base_funs() -> impl Iterator<Item = Filter<Native<Val>>> {
+    base().into_vec().into_iter().map(run)
 }
 
 fn box_once_err<'a>(r: ValR) -> BoxIter<'a, ValX<'a>> {
     box_once(r.map_err(Exn::from))
 }
 
-fn base_funs() -> Box<[Filter<RunPtr<Val>>]> {
+fn base() -> Box<[Filter<RunPtr<Val>>]> {
     Box::new([
         ("tojson", v(0), |_, cv| {
             box_once(Ok(cv.1.to_string().into()))
@@ -472,6 +476,7 @@ impl Val {
         }
     }
 
+    #[cfg(feature = "parse")]
     /// If the value is a string, return it, else fail.
     fn as_str(&self) -> Result<&Rc<String>, Error> {
         match self {
@@ -884,7 +889,16 @@ fn float_eq(left: f64, right: f64) -> bool {
 
 fn float_cmp(left: f64, right: f64) -> Ordering {
     if left == 0. && right == 0. {
+        // consider negative and positive 0 as equal
         Ordering::Equal
+    } else if left.is_nan() {
+        // there are more than 50 shades of NaN, and which of these
+        // you strike when you perform a calculation is not deterministic (!),
+        // therefore `total_cmp` may yield different results for the same calculation
+        // so we bite the bullet and handle this like in jq
+        Ordering::Less
+    } else if right.is_nan() {
+        Ordering::Greater
     } else {
         f64::total_cmp(&left, &right)
     }
@@ -931,11 +945,11 @@ impl fmt::Display for Val {
             }
             Self::Obj(o) => {
                 write!(f, "{{")?;
-                let mut iter = o.iter();
+                let mut iter = o.iter().map(|(k, v)| (Val::Str(k.clone()), v));
                 if let Some((k, v)) = iter.next() {
-                    write!(f, "{k:?}:{v}")?;
+                    write!(f, "{k}:{v}")?;
                 }
-                iter.try_for_each(|(k, v)| write!(f, ",{k:?}:{v}"))?;
+                iter.try_for_each(|(k, v)| write!(f, ",{k}:{v}"))?;
                 write!(f, "}}")
             }
         }
