@@ -1,17 +1,20 @@
+use jaq_json::{Error, Val, ValR};
 use serde_json::Value;
 
-fn yields(x: jaq_interpret::Val, f: &str, ys: impl Iterator<Item = jaq_interpret::ValR>) {
-    let mut ctx = jaq_interpret::ParseCtx::new(Vec::new());
-    ctx.insert_natives(jaq_core::core());
-    ctx.insert_defs(jaq_std::std());
+fn yields(x: Val, code: &str, ys: impl Iterator<Item = ValR>) {
+    use jaq_core::load::{Arena, File, Loader};
 
-    let f = jaq_syn::parse(f, |p| p.module(|p| p.term()))
-        .unwrap()
-        .conv(f);
-    ctx.yields(x, f, ys)
+    let arena = Arena::default();
+    let loader = Loader::new(jaq_std::defs());
+    let modules = loader.load(&arena, File { path: (), code }).unwrap();
+    let filter = jaq_core::Compiler::default()
+        .with_funs(jaq_std::funs())
+        .compile(modules)
+        .unwrap();
+    filter.yields(x, ys)
 }
 
-pub fn fail(x: Value, f: &str, err: jaq_interpret::Error) {
+pub fn fail(x: Value, f: &str, err: Error) {
     yields(x.into(), f, core::iter::once(Err(err)))
 }
 
