@@ -16,6 +16,7 @@ static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
 fn main() -> ExitCode {
     use env_logger::Env;
+    use is_terminal::IsTerminal;
     env_logger::Builder::from_env(Env::default().filter_or("LOG", "debug"))
         .format(|buf, record| match record.level() {
             // format error messages (yielded by `stderr`) without newline
@@ -42,7 +43,6 @@ fn main() -> ExitCode {
     }
 
     let no_color = std::env::var("NO_COLOR").map_or(false, |v| !v.is_empty());
-    let detect_color = |stream| atty::is(stream) && !no_color;
     let set_color = |on| {
         if on {
             yansi::enable();
@@ -51,12 +51,12 @@ fn main() -> ExitCode {
         }
     };
 
-    set_color(!cli.in_place && cli.color_if(|| detect_color(atty::Stream::Stdout)));
+    set_color(!cli.in_place && cli.color_if(|| std::io::stdout().is_terminal() && !no_color));
 
     match real_main(&cli) {
         Ok(exit) => exit,
         Err(e) => {
-            set_color(cli.color_if(|| detect_color(atty::Stream::Stderr)));
+            set_color(cli.color_if(|| std::io::stderr().is_terminal() && !no_color));
             e.report()
         }
     }
@@ -134,6 +134,12 @@ fn binds(cli: &Cli) -> Result<Vec<(String, Val)>, Error> {
         let s = s.to_owned();
         Ok((k.to_owned(), Val::Str(s.into())))
     });
+    let argjson = cli.argjson.iter().map(|(k, s)| {
+        use hifijson::token::Lex;
+        let mut lexer = hifijson::SliceLexer::new(s.as_bytes());
+        let err = |e| Error::Parse(format!("{e} (for value passed to `--argjson {k}`)"));
+        Ok((k.to_owned(), lexer.exactly_one(Val::parse).map_err(err)?))
+    });
     let rawfile = cli.rawfile.iter().map(|(k, path)| {
         let s = std::fs::read_to_string(path).map_err(|e| Error::Io(Some(format!("{path:?}")), e));
         Ok((k.to_owned(), Val::Str(s?.into())))
@@ -146,7 +152,7 @@ fn binds(cli: &Cli) -> Result<Vec<(String, Val)>, Error> {
     let positional = cli.args.iter().cloned().map(|s| Ok(Val::from(s)));
     let positional = positional.collect::<Result<Vec<_>, Error>>()?;
 
-    let var_val = arg.chain(rawfile).chain(slurpfile);
+    let var_val = arg.chain(rawfile).chain(slurpfile).chain(argjson);
     let mut var_val = var_val.collect::<Result<Vec<_>, Error>>()?;
 
     var_val.push(("ARGS".to_string(), args(&positional, &var_val)));
@@ -463,7 +469,7 @@ fn fmt_val(f: &mut Formatter, opts: &PpOpts, level: usize, v: &Val) -> fmt::Resu
         Val::Obj(o) => {
             '{'.bold().fmt(f)?;
             let kv = |f: &mut Formatter, (k, val): (&std::rc::Rc<String>, &Val)| {
-                write!(f, "{:?}:", k.bold())?;
+                write!(f, "{}:", Val::Str(k.clone()).bold())?;
                 if !opts.compact {
                     write!(f, " ")?;
                 }
